<?php

namespace App\Console\Commands\Lab;

use App\Repositories\Enums\ModelStatusEnum;
use App\Repositories\Enums\School\TeachTypeEnum;
use App\Repositories\Models\Base\Admin;
use App\Repositories\Models\School\LessonSchedule;
use App\Repositories\Models\School\Grade;
use App\Repositories\Models\School\Lesson;
use App\Repositories\Models\School\LessonTeacher;
use App\Repositories\Models\School\Room;
use App\Repositories\Models\School\Teacher;
use App\Repositories\Models\School\Term;
use App\Repositories\Models\School\Time;
use Carbon\Carbon;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\DB;

/**
 * Class PresenterCommand
 * @package Prettus\Repository\Generators\Commands
 * @author Anderson Andrade <contato@andersonandra.de>
 */
class ImportLessonSchedulesCommand extends Command
{
    /**
     * The name of command.
     *
     * @var string
     */
    protected $name = 'lab:import';
    /**
     * The description of command.
     *
     * @var string
     */
    protected $description = 'import schedules.';
    /**
     * The type of class being generated.
     *
     * @var string
     */
    protected $type = 'lab';

    private $path = '';

    /**
     * Execute the command.
     *
     * @return void
     * @see fire()
     */
    public function handle()
    {
        $this->path = 'lesson.xls';

        LessonTeacher::query()->truncate();
        LessonSchedule::query()->truncate();
//        Time::query()->truncate();
        Grade::query()->truncate();
        Lesson::query()->truncate();
        Room::query()->truncate();

        try {

//        $path = Storage::path($this->path);
//            $path = base_path('public/实验执行计划表.xls');
            $path = base_path('public/mead.xlsx');

            $term_id = 1;
            $start_day = Term::query()->where('id', $term_id)->value('start_date');

            $config = ['path' => ''];
            $excel = new \Vtiful\Kernel\Excel($config);
            $excel->openFile($path)
                ->openSheet();
//            ->setSkipRows(1);

            //处理数据
            $data = [];
            $lessonRoom = [];
            $lessonHourRoom = 0;
            $testRoom = [];
            while (($row = $excel->nextRow()) !== NULL) {
                $nums = count($row);
                if ($nums == 13) {
                    list(
                        $department,
                        $floor,
                        $room_no,
                        $room,
                        $lesson,
                        $lesson_hour,
                        $class_index,
                        $class_nums,
                        $test_name,
                        $test_class,
                        $test_student_nums,
                        $teacher,
                        $time
                        ) = $row;

                    if ($department == '实验室所属部门') continue;

                    if (!empty($lesson)) {
                        $lesson = $this->decodeLesson($lesson);
                        $lessonRoom = $lesson;
                    }

                    if ($lesson_hour) {
                        $lessonHourRoom = $lesson_hour;
                    }

                    if ($test_name) {
                        $test_name = $this->decodeLesson($test_name);
                        $testRoom = $test_name;
                    }

                    $class = $this->decodeTestClass($test_class);

                    $teacher = $this->decodeLesson($teacher);

                    $da = $this->decodeTestTime($time);
                    $week = $this->getNum($da[2]);
                    $section = $da[1];
                    $week_index = $this->zh2int($da[0]);
                    $day = Carbon::parse($start_day)->addWeeks($week - 1)->addDays($week_index)->toDateString();

                    $data[] = [
                        'room' => $room,
                        'room_no' => $room_no,
                        'lesson' => $lessonRoom[1],
                        'lesson_no' => $lessonRoom[0],
                        'lesson_hour' => $lessonHourRoom,
                        'test' => $testRoom[1],
                        'test_no' => $testRoom[0],
                        'test_student_nums' => $test_student_nums,
                        'class' => $class[2],
                        'class_no' => $class[0],
                        'class_group' => ((int)$class[1]) - 1,
                        'class_student_nums' => $class_nums,
                        'teacher' => $teacher[1],
                        'teacher_no' => $teacher[0],
                        'section' => $section,
                        'week' => $week,
                        'week_index' => $week_index,
                        'day' => $day,
                        'remark' => '',
                    ];

                } elseif ($nums == 12) {
                    $index = count($data) - 1;
                    $data[$index]['remark'] = $row[11];
                } elseif ($nums == 1) {
                    $this->line($row);
                }
            }
//            $this->table(array_keys($data[0]), $data);
//            dd(1);
            //数据写入
//            DB::beginTransaction();
            $bar = $this->output->createProgressBar(count($data));

            $bar->start();
            foreach ($data as $item) {
                //教室
                $room_id = Room::query()->where('room_no', $item['room_no'])->value('id');
                if (empty($room_id)) {
                    $roomModel = Room::query()->create([
                        'term_id' => $term_id,
                        'name' => $item['room'],
                        'room_no' => $item['room_no'],
                        'max_student_nums' => $item['class_student_nums'],
                        'status' => ModelStatusEnum::OK
                    ]);
                    $room_id = $roomModel->id;
                }

                //节次
                $time_ids = [];
                switch ($item['section']) {
                    case '1-2':
                    case '3-4':
                    case '5-6':
                    case '7-8':
                    case '9-11':
                        $time_id = Time::query()->where('section', $item['section'])->value('id');
                        if (empty($time_id)) {
                            $timeModel = Time::query()->create([
                                'name' => $item['section'],
                                'section' => $item['section'],
                                'status' => ModelStatusEnum::OK
                            ]);
                            $time_id = $timeModel->id;
                        }
                        $time_ids[] = $time_id;
                        break;
                    case '1-4':
                        $time_ids = Time::query()->whereIn('section', ['1-2', '3-4'])->pluck('id')->toArray();
                        break;
                    case '5-8':
                        $time_ids = Time::query()->whereIn('section', ['1-2', '5-8'])->pluck('id')->toArray();
                        break;
                }


                //老师
                $teacher_id = Teacher::query()->where('account', $item['teacher_no'])->value('id');
                if (empty($teacher_id)) {
                    $teacherModel = Teacher::query()->create([
                        'name' => $item['teacher'],
                        'account' => $item['teacher_no'],
                        'password' => $item['teacher_no'],
                        'status' => ModelStatusEnum::OK
                    ]);
                    $teacher_id = $teacherModel->id;
                }
                $teach_teacher_ids = [];
                $teacher_admin_id = Admin::query()->where('type', Teacher::class)->where('type_id', $teacher_id)->value('id');
                $teach_teacher_ids[] = $teacher_id;
                if (!empty($item['remark'])) {
                    $teacher = $this->decodeLesson($item['remark']);
                    $teacher_remark_id = Teacher::query()->where('account', $teacher['0'])->value('id');
                    if (empty($teacher_remark_id)) {
                        $teacherRemarkModel = Teacher::query()->create([
                            'name' => $teacher[1],
                            'account' => $teacher[0],
                            'password' => $teacher[0],
                            'status' => ModelStatusEnum::OK
                        ]);
                        $teacher_remark_id = $teacherRemarkModel->id;
                    }
                    $teach_teacher_ids[] = $teacher_remark_id;
                }
                //课程
                $lesson_id = Lesson::query()->where('no', $item['lesson_no'])->value('id');
                if (empty($lesson_id)) {
                    $lessonModel = Lesson::query()->create([
                        'term_id' => $term_id,
                        'name' => $item['lesson'],
                        'no' => $item['lesson_no'],
                        'status' => ModelStatusEnum::OK
                    ]);
                    $lesson_id = $lessonModel->id;
                }
                //班级
                $grade_id = Grade::query()->where('name', $item['class'])->value('id');
                if (empty($grade_id)) {
                    $gradeModel = Grade::query()->create([
                        'term_id' => $term_id,
                        'name' => $item['class'],
//                        'no' => $item['class_no'],
                        'status' => ModelStatusEnum::OK
                    ]);
                    $grade_id = $gradeModel->id;
                }

                $lessonTeacherModel = LessonTeacher::query()->firstOrCreate([
                    'term_id' => $term_id,
                    'lesson_id' => $lesson_id,
                    'grade_id' => $grade_id,
                    'teacher_id' => $teacher_id,
                ]);

                foreach ($time_ids as $time_id) {
                    LessonSchedule::query()->create([
                        'term_id' => $term_id,
                        'lesson_teacher_id' => $lessonTeacherModel->id,

                        'week' => $item['week'],
                        'week_index' => $item['week_index'],
                        'day' => $item['day'],
                        'time_id' => $time_id,

                        'room_id' => $room_id,
                        'lesson_id' => $lesson_id,
                        'grade_id' => $grade_id,
                        'group' => $item['class_group'],
                        'student_nums' => $item['test_student_nums'],

                        'teach_type' => TeachTypeEnum::SJ,
                        'class_hour' => $item['lesson_hour'],
                        'teach_title' => $item['test'],
                        'teacher_id' => $teacher_id,
                        'teach_teacher_ids' => $teach_teacher_ids,
                        'teacher_admin_id' => $teacher_admin_id,
                        'status' => ModelStatusEnum::OK,
                    ]);
                }

                $bar->advance();
            }
            $bar->finish();
//            DB::commit();

        } catch (\Exception $exception) {
//            DB::rollBack();
            dd($exception);
        }

//        $this->table(array_keys($data[0]), $data);

        $this->line('ok');
    }

    /**
     * 解码课程信息
     * @param $val
     * @return false|string[]
     */
    public function decodeLesson($val)
    {
        $val = trim(str_replace(PHP_EOL, '', $val));
//        $arr = str2arr0(str_replace('[', '', $val), ']');
        $arr = [
            $this->f4($val),
            str_replace('、', '', $this->f6($val)),
        ];
        return $arr;
    }

    public function f4($str)
    {
        $result = [];
        preg_match_all("/(?:\[)(.*)(?:\])/i", $str, $result);
        return $result[1][0];
    }

    public function f6($str)
    {
        $result = [];
        preg_match_all("/(?:\])(.*)/i", $str, $result);
        return $result[1][0];
    }

    /**
     * 处理实验班级
     * @param $val
     * @return false|string[]
     */
    public function decodeTestClass($val)
    {
        $val = trim(str_replace(PHP_EOL, '', $val));
        $arr = [
            $this->f1($val),
            $this->f4($val),
            $this->f3($val),
        ];
        return $arr;
    }

    public function f1($str)
    {
        $result = [];
        preg_match_all("/^(.*)(?:\[)/i", $str, $result);
        return $result[1][0];
    }

    public function f3($str)
    {
        $result = [];
        preg_match_all("/(?:\()(.*)(?:\))/i", $str, $result);
        return $result[1][0];
    }

    /**
     * 处理实验班级
     * @param $val
     * @return false|string[]
     */
    public function decodeTestTime($val)
    {
        $val = trim(str_replace(PHP_EOL, '', $val));
        $arr = [
            $this->f1($val),
            $this->f4($val),
            $this->f3($val),
        ];
        return $arr;
    }

    public function getNum($val)
    {
        preg_match('/\d+/', $val, $number);
        return (int)$number[0];
    }

    public function zh2int($str)
    {
        $map = [
            '一', '二', '三', '四', '五', '六', '日',
        ];
        return array_search($str, $map);
    }

    public function f2($str)
    {
        $result = [];
        preg_match_all("/(?:<)(.*)(?:>)/i", $str, $result);
        return $result[1][0];
    }

    public function f5($str)
    {
        $result = [];
        preg_match_all("/(?:\{)(.*)(?:\})/i", $str, $result);
        return $result[1][0];
    }
}
