<?php

namespace App\Console\Commands\Lab;

use App\Imports\Lab\ImportLessonSchedules;
use App\Repositories\Enums\CheckStatusEnum;
use App\Repositories\Enums\ModelStatusEnum;
use App\Repositories\Enums\Navigation\TypeEnum;
use App\Repositories\Enums\Navigation\VisitTypeEnum;
use App\Repositories\Enums\PermissionEnum;
use App\Repositories\Enums\Qunali\EventEnum;
use App\Repositories\Enums\School\TeachTypeEnum;
use App\Repositories\Models\Area\Area;
use App\Repositories\Models\Area\Projects;
use App\Repositories\Models\Base\Admin;
use App\Repositories\Models\Base\Resource;
use App\Repositories\Models\Base\Role;
use App\Repositories\Models\Course\Chapter;
use App\Repositories\Models\Course\Course;
use App\Repositories\Models\Course\Video;
use App\Repositories\Models\Lab\AccountApply;
use App\Repositories\Models\Lab\ImportRecord;
use App\Repositories\Models\News\Message;
use App\Repositories\Models\News\Notice;
use App\Repositories\Models\News\UserMessage;
use App\Repositories\Models\School\LessonSchedule;
use App\Repositories\Models\Navigation\Category;
use App\Repositories\Models\Navigation\UserOrganization;
use App\Repositories\Models\Navigation\Website;
use App\Repositories\Models\Qunali\Organization;
use App\Repositories\Models\Qunali\Point;
use App\Repositories\Models\Qunali\PointEvent;
use App\Repositories\Models\School\Grade;
use App\Repositories\Models\School\Lesson;
use App\Repositories\Models\School\LessonTeacher;
use App\Repositories\Models\School\Room;
use App\Repositories\Models\School\ScheduleApproveLog;
use App\Repositories\Models\School\ScheduleApproveRecord;
use App\Repositories\Models\School\Student;
use App\Repositories\Models\School\Teacher;
use App\Repositories\Models\School\Term;
use App\Repositories\Models\School\Time;
use App\Repositories\Models\TCM\Combinations;
use App\Repositories\Models\TCM\Prescription;
use App\Repositories\Models\TCM\Recipels;
use App\Repositories\Models\User\User;
use App\Services\CombinationService;
use App\Services\TencentMapService;
use Carbon\Carbon;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;
use Maatwebsite\Excel\Facades\Excel;
use Spatie\Permission\Models\Permission;

/**
 * Class PresenterCommand
 * @package Prettus\Repository\Generators\Commands
 * @author Anderson Andrade <contato@andersonandra.de>
 */
class InitDataCommand extends Command
{
    /**
     * The name of command.
     *
     * @var string
     */
    protected $name = 'lab:init:data';
    /**
     * The description of command.
     *
     * @var string
     */
    protected $description = 'init data.';
    /**
     * The type of class being generated.
     *
     * @var string
     */
    protected $type = 'lab';

    /**
     * Execute the command.
     *
     * @return void
     * @see fire()
     */
    public function handle()
    {
//        $this->clearData();
//        $this->initTime();
//        $this->initPermissions();
        $week = ceil((Carbon::parse('2022-02-28')->diffInDays(optional(Term::byId(1))->start_date) + 1) / 7);
        $this->line(Carbon::parse('2022-05-02')->diffInWeeks(optional(Term::byId(1))->start_date));
        $this->line(Carbon::parse('2022-05-02')->diffInDays(optional(Term::byId(1))->start_date));
        $this->line(optional(Term::byId(1))->start_date);
        $this->line($week);
        $this->line('ok');
    }

    public function clearData()
    {
        Admin::query()->where('id', '>', 1)->delete();
        Student::query()->truncate();
        Teacher::query()->truncate();
        Resource::query()->truncate();
        Lesson::query()->truncate();
        Grade::query()->truncate();
        LessonSchedule::query()->truncate();
        LessonTeacher::query()->truncate();
        Room::query()->truncate();
        ScheduleApproveRecord::query()->truncate();
        ScheduleApproveLog::query()->truncate();
        Message::query()->truncate();
        Notice::query()->truncate();
        UserMessage::query()->truncate();
        AccountApply::query()->truncate();
        ImportRecord::query()->truncate();
        \App\Repositories\Models\Lab\LessonSchedule::query()->truncate();
        \App\Repositories\Models\Lab\LessonTeacher::query()->truncate();
        \App\Repositories\Models\Lab\Maintain::query()->truncate();
        \App\Repositories\Models\Lab\OpenAppointment::query()->truncate();
        \App\Repositories\Models\Lab\OpenAppointmentLog::query()->truncate();
    }

    public function initPermissions()
    {

        $admin_ps = [
            //开放预约
            PermissionEnum::controller_openAppointment_check_list,
            PermissionEnum::controller_openAppointment_check_add,
            PermissionEnum::controller_openAppointment_check_del,
            PermissionEnum::controller_openAppointment_check_SYZX,
            PermissionEnum::controller_openAppointment_check_YX,
            PermissionEnum::model_openAppointment_all,

            //排课
            PermissionEnum::controller_schedule_list,
            PermissionEnum::controller_schedule_add,
            PermissionEnum::controller_schedule_del,
//            PermissionEnum::controller_schedule_stop,
            PermissionEnum::controller_schedule_change,
            PermissionEnum::controller_schedule_check_YX,
            PermissionEnum::controller_schedule_check_SYZX,
            PermissionEnum::controller_schedule_pause,
            PermissionEnum::controller_schedule_export,
            PermissionEnum::controller_schedule_batch_stop,
            PermissionEnum::controller_schedule_batch_change,
            PermissionEnum::controller_schedule_recordExport,
            PermissionEnum::model_schedule_all,

            //账号管理
            PermissionEnum::controller_account_check,
            PermissionEnum::controller_account_add,
            PermissionEnum::controller_account_list,
            PermissionEnum::controller_account_del,
            PermissionEnum::controller_account_authorization,
            PermissionEnum::controller_account_import,

            /**
             * 通知公告审核
             */
            PermissionEnum::controller_notice_list,
            PermissionEnum::controller_notice_add,
            PermissionEnum::controller_notice_del,
            PermissionEnum::controller_message_list,
            PermissionEnum::controller_message_add,
            PermissionEnum::controller_message_del,

            /**
             * 维护
             */
            PermissionEnum::controller_maintain_list,
            PermissionEnum::controller_maintain_add,
            PermissionEnum::controller_maintain_del,
            PermissionEnum::controller_maintain_export,
            PermissionEnum::model_maintain_all,

            /**
             * 实验室
             */
            PermissionEnum::controller_room_list,
            PermissionEnum::controller_room_add,
            PermissionEnum::controller_room_del,

            PermissionEnum::controller_term_all,
            PermissionEnum::controller_time_all,

            /**
             * 课程
             */
            PermissionEnum::controller_lesson_list,
            PermissionEnum::controller_lesson_add,
            PermissionEnum::controller_lesson_del,

            PermissionEnum::controller_setting_all,
            PermissionEnum::controller_categorySetting_all,
            PermissionEnum::controller_menus_all,
            PermissionEnum::controller_department_all,
            PermissionEnum::controller_role_all,
            PermissionEnum::controller_importSchedule_all,
            PermissionEnum::controller_grade_all,

            PermissionEnum::controller_teachLesson_list,
            PermissionEnum::controller_teachLesson_add,
            PermissionEnum::controller_teachLesson_del,

        ];
        $teacher_ps = [
            //开放预约
            PermissionEnum::controller_openAppointment_check_list,
            PermissionEnum::controller_openAppointment_check_add,
            PermissionEnum::controller_openAppointment_check_del,
            PermissionEnum::model_openAppointment_me,

            //排课
            PermissionEnum::controller_schedule_list,
//            PermissionEnum::controller_schedule_stop,
            PermissionEnum::controller_schedule_change,
            PermissionEnum::controller_schedule_export,
            PermissionEnum::model_schedule_me,

            /**
             * 通知公告审核
             */
            PermissionEnum::controller_notice_list,

            /**
             * 课程
             */
            PermissionEnum::controller_lesson_list,

            PermissionEnum::controller_teachLesson_list,
        ];
        $outside_teacher_ps = [
            //开放预约
            PermissionEnum::controller_openAppointment_check_list,
            PermissionEnum::controller_openAppointment_check_add,
            PermissionEnum::controller_openAppointment_check_del,
            PermissionEnum::model_openAppointment_me,

            //排课
            PermissionEnum::controller_schedule_list,
//            PermissionEnum::controller_schedule_stop,
            PermissionEnum::controller_schedule_change,
            PermissionEnum::controller_schedule_export,
            PermissionEnum::model_schedule_me,

            /**
             * 通知公告审核
             */
            PermissionEnum::controller_notice_list,

            /**
             * 课程
             */
            PermissionEnum::controller_lesson_list,

            PermissionEnum::controller_teachLesson_list,
        ];
        $maintain_ps = [
            //开放预约
            PermissionEnum::controller_openAppointment_check_list,
            PermissionEnum::model_openAppointment_all,

            //排课
            PermissionEnum::controller_schedule_list,
            PermissionEnum::model_schedule_all,

            /**
             * 通知公告审核
             */
            PermissionEnum::controller_notice_list,

            /**
             * 维护
             */
            PermissionEnum::controller_maintain_list,
            PermissionEnum::controller_maintain_add,
            PermissionEnum::controller_maintain_del,
            PermissionEnum::controller_maintain_export,
            PermissionEnum::model_maintain_me,

            PermissionEnum::controller_room_list,

            /**
             * 课程
             */
            PermissionEnum::controller_lesson_list,

            PermissionEnum::controller_teachLesson_list,
        ];
        //院系管理员
        $yx_ps = [
            //开放预约
            PermissionEnum::controller_openAppointment_check_YX,
            PermissionEnum::model_openAppointment_all,

            //排课
            PermissionEnum::controller_schedule_list,
            PermissionEnum::controller_schedule_check_YX,
            PermissionEnum::controller_schedule_export,
            PermissionEnum::model_schedule_all,

            /**
             * 通知公告审核
             */
            PermissionEnum::controller_notice_list,

            /**
             * 课程
             */
            PermissionEnum::controller_lesson_list,

            PermissionEnum::controller_teachLesson_list,
        ];


        DB::statement('SET FOREIGN_KEY_CHECKS = 0'); // 禁用外键约束
        Permission::query()->truncate();
        DB::table('base_model_has_permissions')->truncate();
        DB::table('base_role_has_permissions')->truncate();

        DB::statement('SET FOREIGN_KEY_CHECKS = 1'); // 启用外键约束

        $permissions = PermissionEnum::makePermissions();
        foreach ($permissions as $item) {
            $item['guard_name'] = 'admins';
            Permission::query()->firstOrCreate($item, []);
        }

        //管理员
        $admin_permissions = Permission::query()->whereIn('name', $admin_ps)->get();
        $admin_role = Role::query()->where('name', 'admin')->first();
        $admin_role->givePermissionTo($admin_permissions);

//        //老师
        $teacher_permissions = Permission::query()->whereIn('name', $teacher_ps)->get();
        $teacher_role = Role::query()->where('name', 'teacher')->first();
        $teacher_role->givePermissionTo($teacher_permissions);
//
//        //学生
        $student_permissions = Permission::query()->whereIn('name', $maintain_ps)->get();
        $student_role = Role::query()->where('name', 'maintain')->first();
        $student_role->givePermissionTo($student_permissions);
//
//        //院系管理员
        $faculty_permissions = Permission::query()->whereIn('name', $yx_ps)->get();
        $faculty_role = Role::query()->where('name', 'faculty_administrator')->first();
        $faculty_role->givePermissionTo($faculty_permissions);

        $outside_teacher_permissions = Permission::query()->whereIn('name', $outside_teacher_ps)->get();
        $outside_teacher_role = Role::query()->where('name', 'outside_teacher')->first();
        $outside_teacher_role->givePermissionTo($outside_teacher_permissions);
    }

    public function initTime()
    {
        Time::query()->truncate();

        Time::query()->firstOrCreate([
            'name' => '1-2',
            'section' => '1-2',
        ], [
            'name' => '1-2',
            'section' => '1-2',
            'start_time' => '08:30',
            'end_time' => '10:00',
            'type' => 1,
            'status' => ModelStatusEnum::OK,
        ]);

        Time::query()->firstOrCreate([
            'name' => '3-4',
            'section' => '3-4',
        ], [
            'name' => '3-4',
            'section' => '3-4',
            'start_time' => '10:20',
            'end_time' => '11:50',
            'type' => 1,
            'status' => ModelStatusEnum::OK,
        ]);


        Time::query()->firstOrCreate([
            'name' => '5-6',
            'section' => '5-6',
        ], [
            'name' => '5-6',
            'section' => '5-6',
            'start_time' => '14:30',
            'end_time' => '16:00',
            'type' => 3,
            'status' => ModelStatusEnum::OK,
        ]);

        Time::query()->firstOrCreate([
            'name' => '7-8',
            'section' => '7-8',
        ], [
            'name' => '7-8',
            'section' => '7-8',
            'start_time' => '16:20',
            'end_time' => '17:50',
            'type' => 3,
            'status' => ModelStatusEnum::OK,
        ]);

        Time::query()->firstOrCreate([
            'name' => '9-11',
            'section' => '9-11',
        ], [
            'name' => '9-11',
            'section' => '9-11',
            'start_time' => '19:00',
            'end_time' => '20:50',
            'type' => 5,
            'status' => ModelStatusEnum::OK,
        ]);
    }
}
