<?php

namespace App\Exports\School;

use App\Repositories\Enums\ModelStatusEnum;
use App\Repositories\Enums\SexEnum;
use App\Repositories\Models\School\LessonSchedule;
use App\Repositories\Models\School\Room;
use App\Repositories\Models\School\Student;
use App\Repositories\Models\School\Time;
use Maatwebsite\Excel\Concerns\Exportable;
use Maatwebsite\Excel\Concerns\FromQuery;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithColumnWidths;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\WithMapping;
use Maatwebsite\Excel\Concerns\WithStyles;
use PhpOffice\PhpSpreadsheet\Style\Alignment;
use PhpOffice\PhpSpreadsheet\Worksheet\Worksheet;


class ScheduleExport implements FromQuery, WithMapping, WithHeadings, ShouldAutoSize, WithColumnWidths, WithStyles
{
    use Exportable;

    protected $rowNums = 0;
    protected $room_id = 0;
    protected $term_id = 0;
    protected $fields = [];

    public function __construct($term_id, $room_id)
    {
        $this->room_id = $room_id;
        $this->term_id = $term_id;
    }

    public function query()
    {
        $room_id = $this->room_id;
        return LessonSchedule::query()->with(['lesson', 'teacher', 'grade', 'room', 'time'])->where('term_id', $this->term_id)->when($room_id, function ($query) use ($room_id) {
            return $query->where('room_id', $room_id);
        })->where('status', ModelStatusEnum::OK)->orderBy('day')->orderBy('time_id');
    }

    public function headingRow(): int
    {
        return 2;
    }

    public function headings(): array
    {
        $room_name = '实验中心-教室任务清单';
        if ($this->room_id) {
            $room_name = Room::query()->where('id', $this->room_id)->value('name') . '-教室任务清单';
        }

        $data[] = [$room_name];

        $bases = [
            '序号',
            '实验室名称',
            '周数',
            '星期',
            '节次',
            '课程名称',
            '任课教师',
            '班级',
            '分组',
            '人数',
            '授课内容',
        ];
//        $data[1] = '序号';
//        foreach ($this->fields as $field) {
//            $data[1] = $bases[$field];
//        }
        $data[] = $bases;
        return $data;
    }

    public function columnWidths(): array
    {
        $bases = [
            'A' => 8,
            'B' => 30,
            'C' => 8,
            'D' => 20,
            'E' => 10,
            'F' => 30,
            'G' => 20,
            'H' => 40,
            'I' => 10,
            'J' => 10,
            'K' => 30,
        ];
//        $data['A'] = 8;
//        $values = array_values($bases);
//        $keys = array_keys($bases);
//        foreach ($this->fields as $field) {
//            $key = $keys[$field];
//            $data["{$key}"] = $values[$field];
//        }
        $data = $bases;
        return $data;
    }

    public function styles(Worksheet $sheet)
    {
        $cellRange = 'A1:K1';
        $sheet->getStyle($cellRange)->getFont()->setSize(12);

        $sheet->getDefaultRowDimension()->setRowHeight(40);//设置行高

        // 文字居中
        $lastrow = $sheet->getHighestRow();
        $sheet->getStyle('A1:K' . $lastrow)->getAlignment()->setVertical(Alignment::VERTICAL_CENTER);//垂直居中
        $sheet->getStyle('A1:K' . $lastrow)->getAlignment()->setHorizontal(Alignment::HORIZONTAL_CENTER);
        $sheet->getStyle('A1:K' . $lastrow)->getAlignment()->setWrapText(true);

        $sheet->mergeCells('A1:K1'); //合并
        $sheet->getStyle('A1:K1')->getFont()->setSize(16);
    }

    public function map($row): array
    {
        $this->rowNums++;
//        $room_name = Room::query()->where('id', $row['room_id'])->value('name');
        $week_name = '星期' . LessonSchedule::weekInt2name($row['week_index']) . "(" . $row['day'] . ")";
//        $time_name = Time::query()->where('id', $row['time_id'])->value('name');
        $group_name = LessonSchedule::groupInt2Name($row['group']);
        if (isset($row['lesson']['name'])) {
            $bases = [
                $this->rowNums,
                $row['room']['name'],
                $row['week'],
                $week_name,
                $row['time']['name'],
                $row['lesson']['name'],
                isset($row['teacher']['name']) ? $row['teacher']['name'] : '',
                $row['grade']['name'],
                $group_name,
                $row['student_nums'],
                $row['teach_title'] ?? ''
            ];
            $data = $bases;
//        foreach ($this->fields as $field) {
//            $data[] = $bases[$field];
//        }
            return $data;
        }
        return [];
    }


}

