<?php

namespace App\Exports\School;

use App\Repositories\Enums\SexEnum;
use App\Repositories\Models\School\Teacher;
use App\Repositories\Models\User\Student;
use Maatwebsite\Excel\Concerns\Exportable;
use Maatwebsite\Excel\Concerns\FromQuery;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithColumnWidths;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\WithMapping;
use Maatwebsite\Excel\Concerns\WithStyles;
use PhpOffice\PhpSpreadsheet\Style\Alignment;
use PhpOffice\PhpSpreadsheet\Worksheet\Worksheet;


class TeacherExport implements FromQuery, WithMapping, WithHeadings, ShouldAutoSize, WithColumnWidths, WithStyles
{
    use Exportable;

    protected $rowNums = 0;
    protected $ids = [];
    protected $fields = [];

    public function __construct(array $fields)
    {
        $this->fields = $fields;
    }

    public function forIds(array $ids)
    {
        $this->ids = $ids;

        return $this;
    }

    public function query()
    {
        return Teacher::query()->whereIn('id', $this->ids);
    }

    public function headings(): array
    {
        $bases = [
            '序号',
            '工号（账号）',
            '姓名',
            '性别',
            '电话',
            '邮箱',
            '毕业院校',
            '学科',
            '职称',
            '担任课程',
            '密码',
        ];
        $data[] = '序号';
        foreach ($this->fields as $field) {
            $data[] = $bases[$field];
        }
        return $data;
    }

    public function columnWidths(): array
    {
        $bases = [
            'A' => 8,
            'B' => 30,
            'C' => 10,
            'D' => 30,
            'E' => 15,
            'F' => 40,
            'G' => 40,
            'H' => 30,
            'I' => 30,
            'J' => 30,
            'K' => 30,
        ];
        $data['A'] = 8;
        $values = array_values($bases);
        $keys = array_keys($bases);
        foreach ($this->fields as $field) {
            $key = $keys[$field];
            $data["{$key}"] = $values[$field];
        }
        return $data;
    }

    public function styles(Worksheet $sheet)
    {
        $cellRange = 'A1:K1';
        $sheet->getStyle($cellRange)->getFont()->setSize(12);

        $sheet->getDefaultRowDimension()->setRowHeight(40);//设置行高

        // 文字居中
        $lastrow = $sheet->getHighestRow();
        $sheet->getStyle('A1:K' . $lastrow)->getAlignment()->setVertical(Alignment::VERTICAL_CENTER);//垂直居中
        $sheet->getStyle('A1:K' . $lastrow)->getAlignment()->setHorizontal(Alignment::HORIZONTAL_CENTER);
        $sheet->getStyle('A1:K' . $lastrow)->getAlignment()->setWrapText(true);

    }

    public function map($row): array
    {
        $this->rowNums++;

        $bases = [
            $this->rowNums,
            $row['account'],
            $row['name'],
            SexEnum::getDescription($row['sex']),
            $row['mobile'] . ' ',
            $row['email'],
            $row['colleges'],
            $row['subject'],
            $row['professional_rank'],
            $row['course'],
            $row['password']
        ];
        $data[] = $this->rowNums;
        foreach ($this->fields as $field) {
            $data[] = $bases[$field];
        }
        return $data;
    }


}

