<?php

namespace App\Http\Controllers\Admin\Base;

use App\Http\Controllers\Controller;
use App\Repositories\Enums\ResponseCodeEnum;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Jiannei\Response\Laravel\Support\Facades\Response;
use Prettus\Validator\Contracts\ValidatorInterface;
use App\Contracts\Repositories\Base\RoleRepository;
use App\Repositories\Validators\Base\RoleValidator;

/**
 * Class RolesController.
 *
 * @package namespace App\Http\Controllers\Admin\Base;
 */
class RoleController extends Controller
{
    /**
     * @var RoleRepository
     */
    protected $repository;

    /**
     * @var RoleValidator
     */
    protected $validator;

    /**
     * RolesController constructor.
     *
     * @param RoleRepository $repository
     * @param RoleValidator $validator
     */
    public function __construct(RoleRepository $repository, RoleValidator $validator)
    {
      parent::__construct();
        $this->repository = $repository;
        $this->validator = $validator;
    }

    /**
     * 列表
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * Author: Mead
     */
    public function index()
    {
        $lists = $this->repository->paginate(request('per_page', self::PAGE_NUM));
        return Response::success($lists);
    }

    /**
     * 创建角色
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource|void
     * @throws \Illuminate\Validation\ValidationException
     * Author: Mead
     */
    public function store(Request $request)
    {
        $this->validate($request, $this->validator->getRules(ValidatorInterface::RULE_CREATE));
        try {
            $data = $request->only(array_keys($this->validator->getRules(ValidatorInterface::RULE_CREATE)));
            $role = $this->repository->create($data);
            return Response::success($role);
        } catch (\Exception $e) {
            return $this->error($e);
        }
    }

    /**
     * 角色详情
     * @param $id
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * Author: Mead
     */
    public function show($id)
    {
        $patient = $this->repository->find($id);
        return Response::success($patient);
    }

    /**
     * 更新
     * @param Request $request
     * @param $id
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * @throws \Illuminate\Validation\ValidationException
     * Author: Mead
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, $this->validator->getRules(ValidatorInterface::RULE_UPDATE));
        try {
            $data = $request->only(array_keys($this->validator->getRules(ValidatorInterface::RULE_UPDATE)));
            $role = $this->repository->update($data, $id);
            return Response::success($role);
        } catch (\Exception $e) {
            $this->error($e);
        }
    }

    /**
     * 删除¬
     * @param $id
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * Author: Mead
     */
    public function destroy($id)
    {
        try {
            $re = $this->repository->delete($id);
            if ($re) {
                return Response::success(null, T('successfully delete.'));
            }
            return Response::fail(T('Delete failed.'), ResponseCodeEnum::SERVICE_UPDATE_DATA_ERROR);
        } catch (\Exception $exception) {
            return Response::fail(T('Delete failed.'), ResponseCodeEnum::SERVICE_UPDATE_DATA_ERROR);
        }
    }

    /**
     * 角色列表
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     * Author: Mead
     */
    public function lists()
    {
        $lists = $this->repository->skipPresenter()->orderBy('sort', 'desc')->get(['id', 'nickname', 'name']);
        return Response::success($lists);
    }
}
