<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Http\Controllers\Admin\Dianli;

use App\Http\Controllers\Controller;
use App\Repositories\Enums\Lab\OpenAppointmentStatusEnum;
use App\Repositories\Enums\ModelStatusEnum;
use App\Repositories\Enums\PermissionEnum;
use App\Repositories\Enums\School\LessonScheduleApproveStatusEnum;
use App\Repositories\Enums\School\LessonScheduleStatusEnum;
use App\Repositories\Enums\School\ScheduleTypeEnum;
use App\Repositories\Models\Base\Admin;
use App\Repositories\Models\Dianli\Task;
use App\Repositories\Models\Exam\PaperResult;
use App\Repositories\Models\Lab\OpenAppointment;
use App\Repositories\Models\News\Notice;
use App\Repositories\Models\School\LessonSchedule;
use App\Repositories\Models\School\LessonTeacher;
use App\Repositories\Models\School\Room;
use App\Repositories\Models\School\ScheduleApproveRecord;
use App\Repositories\Presenters\News\NoticePresenter;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;

class HomeController extends Controller
{
    /**
     * 首页统计
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     */
    public function index(Request $request)
    {
        $task_nums = Task::query()->where('status', ModelStatusEnum::OK)->count();
        $day_task_nums = Task::query()->where(function ($query) {
            return $query->where(function ($q) {
                return $q->where('type', 1)->whereDate('start_date', date("Y-m-d"));
            })->orWhere(function ($q) {
                return $q->where('type', 2)->whereDate('start_date', '<=', date("Y-m-d"))->whereDate('end_date', '>', date("Y-m-d"))->where('weeks', 'like', '%-' . date('w') . '-%');
            });
        })->where('status', ModelStatusEnum::OK)->count();

        $monitor_nums = Admin::query()->whereHas('roles', function ($query) {
            return $query->where('name', 'monitor');
        })->where('status', ModelStatusEnum::OK)->count();

        $polling_nums = Admin::query()->whereHas('roles', function ($query) {
            return $query->where('name', 'polling');
        })->where('status', ModelStatusEnum::OK)->count();

        return Response::success(compact('task_nums', 'day_task_nums', 'polling_nums', 'monitor_nums'));
    }

    /**
     * 统计
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\Resource
     */
    public function statistical(Request $request)
    {
        $day = $request->get('day', date('Y-m-d'));

        $where = [];
        if ($this->isCan(PermissionEnum::model_paperResult_me, true)) {
            $where['polling_admin_id'] = login_admin_id();
        }

        if ($this->isCan(PermissionEnum::model_paperResult_monitor, true)) {
            $where['assign_admin_id'] = login_admin_id();
        }

        $task_nums = PaperResult::query()->where($where)->whereDate('day', $day)->where('status', ModelStatusEnum::OK)->count();
        $task_danger_nums = PaperResult::query()->where($where)->whereDate('day', $day)->where('is_exist_danger', 1)->where('status', ModelStatusEnum::OK)->count();
        $task_wait_nums = PaperResult::query()->where($where)->whereDate('day', $day)->where('is_answer', 0)->where('status', ModelStatusEnum::OK)->count();
        $task_over_nums = PaperResult::query()->where($where)->whereDate('day', $day)->where('is_answer', 1)->where('status', ModelStatusEnum::OK)->count();

        return Response::success(compact('task_nums', 'task_danger_nums', 'task_over_nums', 'task_wait_nums'));
    }


}
