<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Jobs\Lab;

use App\Jobs\Job;
use App\Repositories\Enums\Lab\ImportStatusEnum;
use App\Repositories\Enums\ModelStatusEnum;
use App\Repositories\Enums\School\ScheduleTypeEnum;
use App\Repositories\Enums\School\TeachTypeEnum;
use App\Repositories\Models\Base\Admin;
use App\Repositories\Models\Lab\ImportRecord;
use App\Repositories\Models\Lab\Schedule;
use App\Repositories\Models\School\Grade;
use App\Repositories\Models\School\Lesson;
use App\Repositories\Models\Lab\LessonSchedule;
use App\Repositories\Models\Lab\LessonTeacher;
use App\Repositories\Models\School\Room;
use App\Repositories\Models\School\Teacher;
use App\Repositories\Models\School\Term;
use App\Repositories\Models\School\Time;
use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class MergeLessonSchedulesJob extends Job
{

    private $recordModel;

    /**
     * Create a new job instance.
     */
    public function __construct($importRecordId)
    {
        $this->recordModel = ImportRecord::query()->find($importRecordId);
    }

    /**
     * 确定任务应该超时的时间
     *
     * @return \DateTime
     */
    public function retryUntil()
    {
        return Carbon::now()->addHours(8);
    }

    /**
     * Execute the job.
     */
    public function handle()
    {
        $model = $this->recordModel;

        DB::beginTransaction();
        try {
            Log::error('*************合并数据中*****************');
            $schedules = Schedule::query()->where('import_record_id', $model->id)->where('is_clash', 0)->where('status', ModelStatusEnum::OK)->get();
            foreach ($schedules as $schedule) {
                $admin_id = Admin::query()->where('type', Teacher::class)->where('type', $schedule['teacher_id'])->value('id') ?? 0;

                $lesson_teacher = \App\Repositories\Models\School\LessonTeacher::query()->firstOrCreate([
                    'term_id' => $schedule['term_id'],
                    'lesson_id' => $schedule['lesson_id'],
                    'grade_id' => $schedule['grade_id'],
                    'teacher_id' => $schedule['teacher_id'],
                    'status' => ModelStatusEnum::OK,
                    'teacher_admin_id' => $schedule['teacher_admin_id'],
                ], [
                    'student_nums' => $schedule['student_nums'],
                ]);
                $data = [
                    'term_id' => $schedule['term_id'],
                    'lesson_teacher_id' => $lesson_teacher->id,
                    'day' => $schedule['day'],
                    'week' => $schedule['week'],
                    'time_id' => $schedule['time_id'],
                    'week_index' => $schedule['week_index'],
                    'lesson_id' => $schedule['lesson_id'],
                    'grade_id' => $schedule['grade_id'],
                    'group' => $schedule['group'],
                    'student_nums' => $schedule['student_nums'],
                    'room_id' => $schedule['room_id'],
                    'teach_title' => $schedule['teach_title'],
                    'teach_type' => $schedule['teach_type'],
                    'class_hour' => $schedule['class_hour'],
                    'teacher_id' => $schedule['teacher_id'],
                    'teach_teacher_ids' => $schedule['teach_teacher_ids'],
                    'teacher_admin_id' => $schedule['teacher_admin_id'],
                    'admin_id' => $admin_id,
                    'import_record_id' => $model->id,
                    'status' => ModelStatusEnum::OK,
                    'type' => ScheduleTypeEnum::LESSON
                ];

                \App\Repositories\Models\School\LessonSchedule::query()->create($data);

                Log::error('合并：' . $schedule['id'] . '完成');
            }
            DB::commit();
            $model->status = ImportStatusEnum::MERGE_OK;

        } catch (\Exception $exception) {
            DB::rollBack();
            $model->status = ImportStatusEnum::MERGE_ERROR;
            $model->message = $exception;
        }
        $model->save();
        Log::error("-----------完成---------------");
    }

}
