<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Jobs\School;

use App\Jobs\Job;
use App\Repositories\Enums\School\TeacherTypeEnum;
use App\Repositories\Models\Base\Admin;
use App\Repositories\Models\School\Teacher;
use Illuminate\Support\Facades\Storage;

class ImportTeacherJob extends Job
{

    public $timeout = 1200;

    private $path = '';
    private $disk = '';

    /**
     * Create a new job instance.
     */
    public function __construct($disk, $path)
    {
        $this->disk = $disk;
        $this->path = $path;
    }

    /**
     * Execute the job.
     */
    public function handle()
    {
        $config = ['path' => ''];
        $excel = new \Vtiful\Kernel\Excel($config);

        $excel->openFile(Storage::disk($this->disk)->path($this->path))
            ->openSheet()
            ->setSkipRows(1);
        while (($row = $excel->nextRow()) !== NULL) {

            list(
                $account,
                $name,
                $mobile,
                $email,
                $sex_index,
                $subject,
                $colleges,
                $professional_rank,
                $type_index,
                ) = $row;

            if (($account && $name)) {
                if (!Admin::query()->where('username', $account)->exists()) {
                    $sex = 0;
                    switch ($sex_index) {
                        case "男":
                        case 'man':
                            $sex = 1;
                            break;
                        case '女':
                        case 'women':
                            $sex = 2;
                            break;
                    }

                    $data = [
                        'name' => $name,
                        'account' => $account,
                        'mobile' => $mobile,
                        'password' => $account,
                        'sex' => $sex,
                        'email' => $email,
                        'subject' => $subject,
                        'colleges' => $colleges,
                        'professional_rank' => $professional_rank,
                    ];

                    if (empty($type_index)) {
                        $type = TeacherTypeEnum::getKey($type_index);
                        $data['type'] = $type;
                    }

                    Teacher::query()->create($data);
                }
            }
        }
        return true;
    }
}
