<?php

namespace App\Repositories\Criteria\Base;

use App\Repositories\Enums\Base\RoleEnum;
use App\Repositories\Enums\PermissionEnum;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class AdminCriteria.
 *
 * @package namespace App\Repositories\Criteria\Base;
 */
class AdminCriteria implements CriteriaInterface
{
    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {

        if ($this->request->filled('name')) {
            $name = $this->request->get('name');
            $model = $model->where('name', 'like', "%{$name}%");
        }

        if ($this->request->filled('username')) {
            $username = $this->request->get('username');
            $model = $model->where('username', 'like', "%{$username}%");
        }

        if ($this->request->filled('role_name')) {
            $role_name = $this->request->get('role_name');
            $model = $model->whereHas('roles', function ($query) use ($role_name) {
                return $query->where('name', '=', $role_name);
            });
        }

        if ($this->request->filled('role_names')) {
            $role_names = $this->request->get('role_names');
            $model = $model->whereHas('roles', function ($query) use ($role_names) {
                return $query->whereIn('name', $role_names);
            });
        }
//        else {
//            $model = $model->where('is_admin', 1);
//        }

        if ($this->request->filled('department_id')) {
            $department_id = $this->request->get('department_id');
            $model = $model->where('department_id', '=', $department_id);
        }

        if ($this->request->filled('status')) {
            $status = $this->request->get('status');
            $model = $model->where('status', '=', $status);
        }

        $model = $model->orderByDesc('id');

        //权限控制
        $admin = login_admin();
        $source = getControllerAndFunction();
        $controller = $source['controller'];
        $method = $source['method'];

        if (!$admin->can(PermissionEnum::model_admin_all) && !in_array($method, ['show'])) {
            //班长
            if ($admin->can(PermissionEnum::model_admin_monitor)) {
                $model = $model->where('department_id', '=', $admin['department_id']);
            }
        }


        return $model;
    }
}
