<?php

namespace App\Repositories\Criteria\Dianli;

use App\Repositories\Enums\PermissionEnum;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class TaskCriteria.
 *
 * @package namespace App\Repositories\Criteria\Dianli;
 */
class TaskCriteria implements CriteriaInterface
{
    private $request;

    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($this->request->filled('name')) {
            $name = $this->request->get('name');
            $model = $model->where('name', 'like', "%{$name}%");
        }

        if ($this->request->filled('type')) {
            $type = $this->request->get('type');
            $model = $model->where('type', '=', $type);
        }

        if ($this->request->filled('start_date')) {
            $start_date = $this->request->get('start_date');
            $model = $model->where('start_date', '=', $start_date);
        }

        if ($this->request->filled('is_day_task')) {
            $is_day_task = $this->request->get('is_day_task');
            if ($is_day_task) {
                $model = $model->where(function ($query) {
                    return $query->where(function ($q) {
                        return $q->where('type', 1)->whereDate('start_date', date("Y-m-d"));
                    })->orWhere(function ($q) {
                        return $q->where('type', 2)->whereDate('start_date', '<=', date("Y-m-d"))->whereDate('end_date', '>', date("Y-m-d"))->where('weeks', 'like', '%-' . date('w') . '-%');
                    });
                });
            }

        }


        if ($this->request->filled('status')) {
            $status = $this->request->get('status');
            $model = $model->where('status', '=', $status);
        }

        $model = $model->orderByDesc('id');

        //权限控制
        $admin = login_admin();
        $source = getControllerAndFunction();
        $controller = $source['controller'];
        $method = $source['method'];

        if (!$admin->can(PermissionEnum::model_task_all) && !in_array($method, ['show'])) {
            //班长
            if ($admin->can(PermissionEnum::model_task_me)) {
                $model = $model->where('assign_admin_ids', 'like', '%-' . $admin['id'] . '-%');
            }
        }


        return $model;
    }
}
