<?php

namespace App\Repositories\Criteria\Lab;

use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class MaintainCriteria.
 *
 * @package namespace App\Repositories\Criteria\Lab;
 */
class MaintainCriteria implements CriteriaInterface
{
    private $request;

    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($this->request->filled('day')) {
            $day = $this->request->get('day');
            $model = $model->where('day', '=', $day);
        }

        if ($this->request->filled('term_id')) {
            $term_id = $this->request->get('term_id');
            $model = $model->where('term_id', '=', $term_id);
        }

        if ($this->request->filled('week')) {
            $week = $this->request->get('week');
            $model = $model->where('week', '=', $week);
        }

        if ($this->request->filled('week_index')) {
            $week_index = $this->request->get('week_index');
            $model = $model->where('week_index', '=', $week_index);
        }


        if ($this->request->filled('time_id')) {
            $time_id = $this->request->get('time_id');
            $model = $model->where('time_id', '=', $time_id);
        }

        if ($this->request->filled('room_id')) {
            $room_id = $this->request->get('room_id');
            $model = $model->where('room_id', '=', $room_id);
        }

        if ($this->request->filled('admin_name')) {
            $admin_name = $this->request->get('admin_name');
            $model = $model->whereHas('admin', function ($query) use ($admin_name) {
                return $query->where('name', 'like', "%{$admin_name}%");
            });
        }

        if ($this->request->filled('maintain_admin_name')) {
            $maintain_admin_name = $this->request->get('maintain_admin_name');
            $model = $model->whereHas('maintain_admin', function ($query) use ($maintain_admin_name) {
                return $query->where('name', 'like', "%{$maintain_admin_name}%");
            });
        }

        if ($this->request->filled('status')) {
            $status = $this->request->get('status');
            $model = $model->where('status', '=', $status);
        }

        $model = $model->orderByDesc('id');

        return $model;
    }
}
