<?php

namespace App\Repositories\Criteria\Lab;

use App\Repositories\Enums\PermissionEnum;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class OpenAppointmentCriteria.
 *
 * @package namespace App\Repositories\Criteria\Lab;
 */
class OpenAppointmentCriteria implements CriteriaInterface
{
    private $request;

    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($this->request->filled('applicant_name')) {
            $applicant_name = $this->request->get('applicant_name');
            $model = $model->where('applicant_name', 'like', "%{$applicant_name}%");
        }

        if ($this->request->filled('term_id')) {
            $term_id = $this->request->get('term_id');
            $model = $model->where('term_id', '=', $term_id);
        }

        if ($this->request->filled('department')) {
            $department = $this->request->get('department');
            $model = $model->where('department', 'like', "%{$department}%");
        }

        if ($this->request->filled('applicant_mobile')) {
            $applicant_mobile = $this->request->get('applicant_mobile');
            $model = $model->where('applicant_mobile', 'like', "%{$applicant_mobile}%");
        }


        if ($this->request->filled('admin_name')) {
            $admin_name = $this->request->get('admin_name');
            $model = $model->whereHas('admin', function ($query) use ($admin_name) {
                return $query->where('name', 'like', "%{$admin_name}%");
            });
        }

        if ($this->request->filled('status')) {
            $status = $this->request->get('status');
            $model = $model->where('status', '=', $status);
        }

        $model = $model->orderByDesc('id');

        //权限控制
        $admin = login_admin();
        if (!$admin->can(PermissionEnum::model_openAppointment_all)) {
            //教师
            if ($admin->can(PermissionEnum::model_openAppointment_me)) {
                $model = $model->where('admin_id', $admin['id']);
            }
        }
        return $model;
    }
}
