<?php

namespace App\Repositories\Criteria\School;

use App\Repositories\Enums\PermissionEnum;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class ScheduleApproveRecordCriteria.
 *
 * @package namespace App\Repositories\Criteria\School;
 */
class ScheduleApproveRecordCriteria implements CriteriaInterface
{
    private $request;

    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {

        if ($this->request->filled('term_id')) {
            $term_id = $this->request->get('term_id');
            $model = $model->where('term_id', '=', $term_id);
        }

        if ($this->request->filled('lesson_schedule_id')) {
            $lesson_schedule_id = $this->request->get('lesson_schedule_id');
            $model = $model->where('lesson_schedule_id', '=', $lesson_schedule_id);
        }

        if ($this->request->filled('time_id')) {
            $time_id = $this->request->get('time_id');
            $model = $model->where('time_id', '=', $time_id);
        }

        if ($this->request->filled('week_index')) {
            $week_index = $this->request->get('week_index');
            $model = $model->whereHas('schedule', function ($query) use ($week_index) {
                return $query->where('week_index', '=', $week_index);
            });
        }

        if ($this->request->filled('week')) {
            $week = $this->request->get('week');
            $model = $model->whereHas('schedule', function ($query) use ($week) {
                return $query->where('week', '=', $week);
            });
        }

        if ($this->request->filled('lesson_id')) {
            $lesson_id = $this->request->get('lesson_id');
            $model = $model->where('lesson_id', '=', $lesson_id);
        }

        if ($this->request->filled('lesson_name')) {
            $lesson_name = $this->request->get('lesson_name');
            $model = $model->whereHas('lesson', function ($query) use ($lesson_name) {
                return $query->where('name', 'like', "%{$lesson_name}%");
            });
        }

        if ($this->request->filled('type')) {
            $type = $this->request->get('type');
            $model = $model->where('type', '=', $type);
        }

        if ($this->request->filled('day')) {
            $day = $this->request->get('day');
            $model = $model->whereHas('schedule', function ($query) use ($day) {
                return $query->where('day', '=', $day);
            });
        }

        if ($this->request->filled('teacher_id')) {
            $teacher_id = $this->request->get('teacher_id');
            $model = $model->where('teacher_id', '=', $teacher_id);
        }

        if ($this->request->filled('status')) {
            $status = $this->request->get('status');
            $model = $model->where('status', '=', $status);
        }

        $model = $model->where('term_id', $this->request->header('term-id'));
        $model = $model->orderByDesc('id');


        //权限控制
        $admin = login_admin();
        if (!$admin->can(PermissionEnum::model_schedule_all)) {
            //教师
            if ($admin->can(PermissionEnum::model_schedule_me)) {
                $model = $model->where('admin_id', $admin['id']);
            }
        }

        return $model;
    }
}
