<?php

namespace App\Repositories\Models\Dianli;

use App\Repositories\Models\Base\Admin;
use App\Repositories\Models\Exam\Paper;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;
use Prettus\Repository\Contracts\Transformable;
use Prettus\Repository\Traits\TransformableTrait;

/**
 * Class Task.
 *
 * @package namespace App\Repositories\Models\Dianli;
 */
class Task extends Model implements Transformable
{
    use TransformableTrait;

    protected $table = 'dianli_tasks';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $guarded = [];

    public function setAssignAdminIdsAttribute($val)
    {
        $this->attributes['assign_admin_ids'] = '-' . arr2str0($val, '-') . '-';
    }

    public function getAssignAdminIdsAttribute($val)
    {
        return str2arr0(trim($val, '-'), '-');
    }

    public function setWeeksAttribute($val)
    {
        $this->attributes['weeks'] = '-' . arr2str0($val, '-') . '-';
    }

    public function getWeeksAttribute($val)
    {
        return str2arr0(trim($val, '-'), '-');
    }

    public function admin()
    {
        return $this->belongsTo(Admin::class)->select(['id', 'username', 'name']);
    }

    public function getAssignAdminAttribute()
    {
        return Admin::query()->whereIn('id', str2arr0(trim($this->attributes['assign_admin_ids'], '-'), '-'))->select(['id', 'username', 'name'])->get();
    }

    protected static function booted()
    {
        static::created(function (Task $model) {
            $paper = Paper::query()->create([
                'name' => $model->name,
            ]);
            DB::table('dianli_tasks')->where('id', $model->id)->update(['paper_id' => $paper->id]);
        });
    }

    public function paper()
    {
        return $this->belongsTo(Paper::class)->select(['id', 'name', 'submit_nums', 'topic_nums', 'mark']);
    }
}
