<?php

namespace App\Repositories\Models\Lab;

use App\Repositories\Enums\School\ScheduleTypeEnum;
use App\Repositories\Models\Base\Admin;
use App\Repositories\Models\Model;
use App\Repositories\Models\School\Room;
use App\Repositories\Models\School\Time;
use Prettus\Repository\Contracts\Transformable;
use Prettus\Repository\Traits\TransformableTrait;

/**
 * Class Maintain.
 *
 * @package namespace App\Repositories\Models\Lab;
 */
class Maintain extends Model implements Transformable
{
    use TransformableTrait;

    protected $table = 'lab_room_maintains';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $guarded = [];

    protected static function booted()
    {
        self::saved(function (Maintain $maintain) {
            \App\Repositories\Models\School\LessonSchedule::query()->updateOrCreate([
                'type' => ScheduleTypeEnum::MAINTAIN,
                'type_id' => $maintain->id,
            ], [
                'term_id' => $maintain->term_id,
                'day' => $maintain->day,
                'week' => $maintain->week,
                'week_index' => $maintain->week_index,
                'time_id' => $maintain->time_id,
                'room_id' => $maintain->room_id,
                'status' => $maintain->status,
                'teach_title' => '实验室维护',
            ]);
        });

        self::deleted(function (Maintain $maintain) {
            \App\Repositories\Models\School\LessonSchedule::query()->where([
                'type' => ScheduleTypeEnum::MAINTAIN,
                'type_id' => $maintain->id,
            ])->delete();
        });
    }

    public function admin()
    {
        return $this->belongsTo(Admin::class)->select(['id', 'name', 'username']);
    }

    public function room()
    {
        return $this->belongsTo(Room::class)->select(['id', 'name']);
    }

    public function time()
    {
        return $this->belongsTo(Time::class)->select(['id', 'name']);
    }

    public function maintain_admin()
    {
        return $this->belongsTo(Admin::class, 'maintain_admin_id')->select(['id', 'name', 'username']);
    }

}
