<?php

namespace App\Repositories\Models\Lab;

use App\Repositories\Enums\ModelStatusEnum;
use App\Repositories\Models\Base\Admin;
use App\Repositories\Models\Model;
use App\Repositories\Models\School\Grade;
use App\Repositories\Models\School\Lesson;
use App\Repositories\Models\School\Room;
use App\Repositories\Models\School\Teacher;
use App\Repositories\Models\School\Term;
use App\Repositories\Models\School\Time;
use Carbon\Carbon;
use Illuminate\Support\Arr;
use Prettus\Repository\Contracts\Transformable;
use Prettus\Repository\Traits\TransformableTrait;

/**
 * Class LessonSchedule.
 *
 * @package namespace App\Repositories\Models\School;
 */
class Schedule extends Model implements Transformable
{
    use TransformableTrait;

    protected $table = 'lab_lesson_schedules';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $guarded = [];

    public static function byTimeGetDate($term_id, $week, $week_index)
    {
        return Carbon::parse(optional(Term::byId($term_id))->start_date)->addWeeks($week - 1)->addDays($week_index)->toDateString();
    }

    public static function byDateGetWeek($term_id, $day)
    {
        $week = ceil((Carbon::parse($day)->diffInDays(optional(Term::byId($term_id))->start_date) + 1) / 7);
        $w = date('w', strtotime($day));
        switch ($w) {
            case 0:
                $week_index = 6;
                break;
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
                $week_index = $w - 1;
                break;
        }
        return [
            'week' => (int)$week,
            'week_index' => $week_index,
        ];
    }

    public function setTeachTeacherIdsAttribute($val)
    {
        $this->attributes['teach_teacher_ids'] = '-' . arr2str($val, '-') . '-';
    }

    public function getTeachTeacherIdsAttribute($val)
    {
        return str2arr(trim($val, '-'), '-');
    }

    public function getGroupNameAttribute()
    {
        $group = (int)$this->attributes['group'];
        return chr(65 + $group) . '组';
    }

    public function lesson()
    {
        return $this->belongsTo(Lesson::class)->select(['id', 'name']);
    }

    public function teacher()
    {
        return $this->belongsTo(Admin::class, 'teacher_admin_id')->select(['id', 'name', 'username']);
//        return $this->belongsTo(Teacher::class)->select(['id', 'name', 'account']);
    }

    public function grade()
    {
        return $this->belongsTo(Grade::class)->select(['id', 'name']);
    }

    public function room()
    {
        return $this->belongsTo(Room::class)->select(['id', 'name']);
    }

    public function time()
    {
        return $this->belongsTo(Time::class)->select(['id', 'name']);
    }

    /**
     * 检查数据是否冲突
     * @param $id
     * @return int
     */
    public static function checkIsClash($id)
    {
        $schedules = self::query()->where('import_record_id', $id)->where('status', ModelStatusEnum::OK)->get()->toArray();
        $i = 0;
        foreach ($schedules as $schedule) {
            $where = Arr::only($schedule, ['term_id', 'week', 'week_index', 'time_id', 'room_id', 'status', 'day']);
            $is_clash = 0;
            if (\App\Repositories\Models\School\LessonSchedule::query()->where($where)->exists()) {
                $is_clash = 1;
            } else {
                if (self::query()->where('import_record_id', $id)->where($where)->where('id', '<>', $schedule['id'])->exists()) {
                    $is_clash = 1;
                    self::query()->where($where)->where('id', '<>', $schedule['id'])->update(['is_clash' => 1]);
                }
            }

            if ($is_clash) {
                $i++;
                self::query()->where('id', $schedule['id'])->update(['is_clash' => 1]);
            }
        }
        return $i;
    }
}
