<?php

namespace App\Repositories\Models\School;

use App\Repositories\Enums\ModelStatusEnum;
use App\Repositories\Models\Base\Admin;
use App\Repositories\Models\Base\Department;
use App\Repositories\Models\Model;
use Illuminate\Support\Facades\Hash;
use Prettus\Repository\Contracts\Transformable;
use Prettus\Repository\Traits\TransformableTrait;

/**
 * Class Teacher.
 *
 * @package namespace App\Repositories\Models\Mentor;
 */
class Teacher extends Model implements Transformable
{
    use TransformableTrait;

    protected $table = 'school_teachers';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $guarded = [];

    protected $hidden = ['password'];

    protected static function booted()
    {
        static::created(function (Teacher $model) {
            if (Admin::query()->where('username', $model->account)->exists()) {
                Admin::query()->where('username', $model->account)->update([
                    'type' => Teacher::class,
                    'type_id' => $model->id,
                    'is_admin' => 0,
                ]);
            } else {
                $admin = Admin::query()->create([
                    'username' => $model->account,
                    'password' => Hash::make($model->password),
                    'name' => $model->name,
                    'headimg' => $model->headimg,
                    'type' => Teacher::class,
                    'type_id' => $model->id,
                    'is_admin' => 0,
                    'department_id' => $model->department_id ?? 0,
                    'email' => $model->email,
                    'mobile' => $model->mobile,
                    'status' => ModelStatusEnum::OK,
                ]);

                $admin->syncRoles(['teacher']);
            }
        });

        static::updated(function (Teacher $model) {
            $data = [
                'username' => $model->account,
                'name' => $model->name,
                'headimg' => $model->headimg,
                'email' => $model->email,
                'mobile' => $model->mobile,
                'status' => $model->status,
                'department_id' => $model->department_id ?? 0,
            ];

            if ($model->isDirty('password')) {
                $data['password'] = Hash::make($model->password);
            }
            Admin::query()->where('type_id', $model->id)->where('type', Teacher::class)->update($data);
        });

        static::updating(function (Teacher $teacher) {
            if ($teacher->mobile && $teacher->email) {
                $teacher->is_register = 1;
            }
        });

        static::deleted(function (Teacher $model) {
            Admin::query()->where('type_id', $model->id)->where('type', Teacher::class)->delete();
        });
    }

    public function getHeadimgAttribute($val)
    {
        if (empty($val)) {
            return path_to_url('/default/headImg.png');
        }
        return path_to_url($val);
    }

    public function department()
    {
        return $this->belongsTo(Department::class)->select(['id', 'name']);
    }

    public function byIdGetUserId($id)
    {
        return Admin::query()->where('type', Teacher::class)->where('type_id', $id)->value('id') ?? 0;
    }
}
