<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Services\Lab;


use App\Repositories\Enums\CheckStatusEnum;
use App\Repositories\Enums\Lab\OpenAppointmentStatusEnum;
use App\Repositories\Enums\ModelStatusEnum;
use App\Repositories\Enums\PermissionEnum;
use App\Repositories\Enums\School\LessonScheduleApproveStatusEnum;
use App\Repositories\Enums\School\LessonScheduleStatusEnum;
use App\Repositories\Enums\School\ScheduleRecordTypeEnum;
use App\Repositories\Enums\School\ScheduleTypeEnum;
use App\Repositories\Enums\School\TeachTypeEnum;
use App\Repositories\Models\Lab\Maintain;
use App\Repositories\Models\Lab\OpenAppointmentLog;
use App\Repositories\Models\School\LessonSchedule;
use App\Repositories\Models\School\ScheduleApproveLog;
use Carbon\Carbon;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\DB;

class OpenAppointmentService
{
    public function check($term_id, &$model, $check_status, $check_result, $role_index, $is_check = false)
    {
        $id = $model->id;

        $admin_id = login_admin_id();

        if ($model->status == OpenAppointmentStatusEnum::CLOSE) {
            return $this->error('该申请已经关闭');
        }

        if (in_array($model->status, [OpenAppointmentStatusEnum::YX_ERROR, OpenAppointmentStatusEnum::STZX_ERROR])) {
            return $this->error('该申请审核失败，暂不允许操作');
        }

        if (in_array($model->status, [OpenAppointmentStatusEnum::COMPLETE])) {
            return $this->error('该申请已经审核完成，请勿重复操作');
        }

        //检验时间段是否合法
        $use = $model['use_data'];
        foreach ($use as $u) {
            if (!Arr::has($u, ['week', 'week_index', 'time_id', 'room_id'])) {
                return $this->error('参数非法');
            }

            $time = Arr::only($u, ['week', 'week_index', 'time_id', 'room_id']);

            $is_exists = LessonSchedule::query()->where($time)->where('term_id', $model->term_id)->where('status', ModelStatusEnum::OK)->exists();
            if ($is_exists) {
                return $this->error('该时间段不能预约');
            }
        }


        switch ($role_index) {
            default:
            case 0:
                return $this->error('暂无权限');
                break;
            case 1:
                //1.判断是否已经审核
                $is_exist = OpenAppointmentLog::query()->where('status', ModelStatusEnum::OK)->where('open_appointment_id', $model->id)->where('term_id', $term_id)->where('type', ScheduleApproveLog::TYPE_YX)->where('check_status', CheckStatusEnum::OK)->exists();
                if ($is_exist) {
                    return $this->error('该申请已经审核过了，请勿重复操作');
                }

                //学院管理员
                if ($model->status != OpenAppointmentStatusEnum::SYZX_OK) {
                    return $this->error('实验中心审核通过，才能院系审核！');
                }

                if ($is_check) return false;

                $model->status = OpenAppointmentStatusEnum::YX_ERROR;
                if ($check_status == CheckStatusEnum::OK) {
                    $model->status = OpenAppointmentStatusEnum::YX_OK;
                }

                OpenAppointmentLog::query()->create([
                    'open_appointment_id' => $id,
                    'term_id' => $term_id,
                    'type' => ScheduleApproveLog::TYPE_YX,
                    'check_status' => $check_status,
                    'check_result' => $check_result,
                    'check_time' => Carbon::now()->toDateTimeString(),
                    'check_admin_id' => $admin_id,
                    'status' => ModelStatusEnum::OK
                ]);

                $model->save();
                break;
            case 2:
                //1.判断是否已经审核
                $is_exist = OpenAppointmentLog::query()
                    ->where('status', ModelStatusEnum::OK)
                    ->where('open_appointment_id', $id)
                    ->where('term_id', $term_id)
                    ->where('type', ScheduleApproveLog::TYPE_SYZX)
                    ->where('check_status', CheckStatusEnum::OK)
                    ->exists();

                if ($is_exist) {
                    return $this->error('该申请已经审核过了，请勿重复操作');
                }

                //实验中学管理员
                if ($model->status != OpenAppointmentStatusEnum::WAIT) {
                    return $this->error('该申请状态不是待审核状态');
                }

                if ($is_check) return false;

                $model->status = OpenAppointmentStatusEnum::STZX_ERROR;
                if ($check_status == CheckStatusEnum::OK) {
                    $model->status = OpenAppointmentStatusEnum::SYZX_OK;
                }

                OpenAppointmentLog::query()->create([
                    'open_appointment_id' => $id,
                    'term_id' => $term_id,
                    'type' => ScheduleApproveLog::TYPE_SYZX,
                    'check_status' => $check_status,
                    'check_result' => $check_result,
                    'check_time' => Carbon::now()->toDateTimeString(),
                    'check_admin_id' => $admin_id,
                    'status' => ModelStatusEnum::OK
                ]);

                $model->save();

                break;
            case 3:
                if ($is_check) return false;
                //学院管理员+实验中心管理员
                $is_sxzx = 0;
                //1.判断实验中心是否已经审核
                $is_exist = OpenAppointmentLog::query()
                    ->where('status', ModelStatusEnum::OK)
                    ->where('open_appointment_id', $id)
                    ->where('term_id', $term_id)
                    ->where('type', ScheduleApproveLog::TYPE_SYZX)
                    ->where('check_status', CheckStatusEnum::OK)
                    ->exists();
                if (!$is_exist) {
                    OpenAppointmentLog::query()->create([
                        'open_appointment_id' => $id,
                        'term_id' => $term_id,
                        'type' => ScheduleApproveLog::TYPE_SYZX,
                        'check_status' => $check_status,
                        'check_result' => $check_result,
                        'check_time' => Carbon::now()->toDateTimeString(),
                        'check_admin_id' => $admin_id,
                        'status' => ModelStatusEnum::OK
                    ]);

                    if ($check_status == CheckStatusEnum::ERROR) {
                        $model->status = OpenAppointmentStatusEnum::STZX_ERROR;
                        $is_sxzx = 1;
                    }
                }

                //2.判断实验中学是否已经审核
                if (!$is_sxzx) {
                    $is_exist = OpenAppointmentLog::query()->where('status', ModelStatusEnum::OK)->where('open_appointment_id', $id)->where('term_id', $term_id)->where('type', ScheduleApproveLog::TYPE_YX)->where('check_status', CheckStatusEnum::OK)->exists();
                    if (!$is_exist) {
                        OpenAppointmentLog::query()->create([
                            'open_appointment_id' => $id,
                            'term_id' => $term_id,
                            'type' => ScheduleApproveLog::TYPE_YX,
                            'check_status' => $check_status,
                            'check_result' => $check_result,
                            'check_time' => Carbon::now()->toDateTimeString(),
                            'check_admin_id' => $admin_id,
                            'status' => ModelStatusEnum::OK
                        ]);

                        if ($check_status == CheckStatusEnum::ERROR) {
                            $model->status = OpenAppointmentStatusEnum::YX_ERROR;
                            $is_sxzx = 2;
                        }
                    }
                }
                if (!$is_sxzx) $model->status = OpenAppointmentStatusEnum::YX_OK;
                $model->save();
                break;
        }

        if ($model->status == OpenAppointmentStatusEnum::YX_OK) {
            //审核成功
            $schedules = $model->use_data;
            $i = 0;
            DB::beginTransaction();
            foreach ($schedules as $schedule) {
                //插入记录调课
                if (!LessonSchedule::query()->where([
                    'term_id' => $model->term_id,
                    'week' => $schedule['week'],
                    'week_index' => $schedule['week_index'],
                    'day' => $schedule['day'],
                    'time_id' => $schedule['time_id'],
                    'room_id' => $schedule['room_id'],
                ])->exists()) {
                    LessonSchedule::query()->create([
                        'term_id' => $model->term_id,
                        'lesson_teacher_id' => 0,
                        'week' => $schedule['week'],
                        'week_index' => $schedule['week_index'],
                        'day' => $schedule['day'],
                        'time_id' => $schedule['time_id'],
                        'room_id' => $schedule['room_id'],
                        'lesson_id' => 0,
                        'grade_id' => 0,
                        'group' => 0,
                        'student_nums' => $model->use_people_nums,
                        'migrate_id' => 0,
                        'teach_type' => TeachTypeEnum::SJ,
                        'class_hour' => 2,
                        'teach_title' => $model->department,
                        'teacher_id' => 0,
                        'teach_teacher_ids' => 0,
                        'teacher_admin_id' => $model->admin_id,

                        'type' => ScheduleTypeEnum::OPEN_APPOINTMENT,
                        'type_id' => $model['id'],

                        'status' => ModelStatusEnum::OK,
                    ]);
                    $i++;
                }

            }

            if (count($schedules) == $i) {
                $model->status = OpenAppointmentStatusEnum::COMPLETE;
                DB::commit();
            } else {
                $model->status = OpenAppointmentStatusEnum::OPERATION_ERROR;
                DB::rollBack();
            }
        }
        $model->save();
    }

    private function error($msg)
    {
        return $msg;
        return [
            'status' => false,
            'msg' => $msg,
        ];
    }
}
