<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Services\Lab;


use App\Repositories\Enums\CheckStatusEnum;
use App\Repositories\Enums\ModelStatusEnum;
use App\Repositories\Enums\School\LessonScheduleApproveStatusEnum;
use App\Repositories\Enums\School\LessonScheduleStatusEnum;
use App\Repositories\Enums\School\ScheduleRecordTypeEnum;
use App\Repositories\Enums\School\ScheduleTypeEnum;
use App\Repositories\Models\Lab\Maintain;
use App\Repositories\Models\School\LessonSchedule;
use App\Repositories\Models\School\ScheduleApproveLog;
use Carbon\Carbon;
use Illuminate\Support\Arr;

class ScheduleService
{
    public function check($term_id, &$scheduleApproveModel, $check_status, $check_result, $role_index, $is_check = false)
    {

        if ($scheduleApproveModel->status == LessonScheduleApproveStatusEnum::CLOSE) {
            return $this->error('该申请已经关闭');
        }

        if (in_array($scheduleApproveModel->status, [LessonScheduleApproveStatusEnum::YX_ERROR, LessonScheduleApproveStatusEnum::STZX_ERROR])) {
            return $this->error('该申请审核失败，暂不允许操作');
        }

        if (in_array($scheduleApproveModel->status, [LessonScheduleApproveStatusEnum::SYZX_OK, LessonScheduleApproveStatusEnum::OPERATION_ERROR, LessonScheduleApproveStatusEnum::COMPLETE])) {
            return $this->error('该申请已经审核完成，请勿重复操作');
        }

        $schedule_approve_id = $scheduleApproveModel->id;
        $admin_id = login_admin_id();

        if ($scheduleApproveModel->type == ScheduleRecordTypeEnum::TK && $check_status == CheckStatusEnum::OK) {
            //1.判断调到那个地方是否有课
            $migrate_where = Arr::only($scheduleApproveModel->migrate_data, ['week', 'time_id', 'week_index', 'room_id', 'time_id']);
            //查看当前调课是否存在课程
            $is_t_exist = LessonSchedule::query()->where($migrate_where)->where('status', ModelStatusEnum::OK)->first();
            if ($is_t_exist) {
                return $this->error('该申请将要调整的时间和先有课程冲突！');
            }

            $is_m_exist = Maintain::query()->where($migrate_where)->where('status', ModelStatusEnum::OK)->exists();
            if ($is_m_exist) {
                return $this->error('该时间段暂不能用');
            }
        }

        switch ($role_index) {
            default:
            case 0:
                return $this->error('暂无权限');
                break;
            case 1:
                //学院管理员
                if ($scheduleApproveModel->status != LessonScheduleApproveStatusEnum::WAIT) {
                    return $this->error('该记录审核状态与账号权限不匹配');
                }

                //1.判断是否已经审核
                $is_exist = ScheduleApproveLog::query()->where('status', ModelStatusEnum::OK)->where('schedule_approve_id', $schedule_approve_id)->where('term_id', $term_id)->where('type', ScheduleApproveLog::TYPE_YX)->where('check_status', CheckStatusEnum::OK)->exists();
                if ($is_exist) {
                    return $this->error('该申请已经审核过了，请勿重复操作');
                }

                if ($is_check) return false;

                $scheduleApproveModel->status = LessonScheduleApproveStatusEnum::YX_ERROR;
                if ($check_status == CheckStatusEnum::OK) {
                    $scheduleApproveModel->status = LessonScheduleApproveStatusEnum::YX_OK;
                }

                ScheduleApproveLog::query()->create([
                    'schedule_approve_id' => $schedule_approve_id,
                    'term_id' => $term_id,
                    'type' => ScheduleApproveLog::TYPE_YX,
                    'check_status' => $check_status,
                    'check_result' => $check_result,
                    'check_time' => Carbon::now()->toDateTimeString(),
                    'check_admin_id' => $admin_id,
                    'status' => ModelStatusEnum::OK
                ]);

                $scheduleApproveModel->save();
                break;
            case 2:
                //实验中学管理员
                if ($scheduleApproveModel->status != LessonScheduleApproveStatusEnum::YX_OK) {
                    return $this->error('该记录审核状态与账号权限不匹配');
                }

                //1.判断是否已经审核
                $is_exist = ScheduleApproveLog::query()->where('status', ModelStatusEnum::OK)->where('schedule_approve_id', $schedule_approve_id)->where('term_id', $term_id)->where('type', ScheduleApproveLog::TYPE_SYZX)->where('check_status', CheckStatusEnum::OK)->exists();
                if ($is_exist) {
                    return $this->error('该申请已经审核过了，请勿重复操作');
                }

                if ($is_check) return false;

                $scheduleApproveModel->status = LessonScheduleApproveStatusEnum::STZX_ERROR;
                if ($check_status == CheckStatusEnum::OK) {
                    $scheduleApproveModel->status = LessonScheduleApproveStatusEnum::SYZX_OK;
                }

                ScheduleApproveLog::query()->create([
                    'schedule_approve_id' => $schedule_approve_id,
                    'term_id' => $term_id,
                    'type' => ScheduleApproveLog::TYPE_SYZX,
                    'check_status' => $check_status,
                    'check_result' => $check_result,
                    'check_time' => Carbon::now()->toDateTimeString(),
                    'check_admin_id' => $admin_id,
                    'status' => ModelStatusEnum::OK
                ]);

                $scheduleApproveModel->save();

                break;
            case 3:

                if ($is_check) return false;

                //学院管理员+实验中心管理员
                $is_sxzx = 0;
                //1.判断院系是否已经审核
                $is_exist = ScheduleApproveLog::query()->where('status', ModelStatusEnum::OK)->where('schedule_approve_id', $schedule_approve_id)->where('term_id', $term_id)->where('type', ScheduleApproveLog::TYPE_YX)->where('check_status', CheckStatusEnum::OK)->exists();
                if (!$is_exist) {
                    ScheduleApproveLog::query()->create([
                        'schedule_approve_id' => $schedule_approve_id,
                        'term_id' => $term_id,
                        'type' => ScheduleApproveLog::TYPE_YX,
                        'check_status' => $check_status,
                        'check_result' => $check_result,
                        'check_time' => Carbon::now()->toDateTimeString(),
                        'check_admin_id' => $admin_id,
                        'status' => ModelStatusEnum::OK
                    ]);

                    if ($check_status == CheckStatusEnum::ERROR) {
                        $scheduleApproveModel->status = LessonScheduleApproveStatusEnum::YX_ERROR;
                        $is_sxzx = 1;
                    }
                }

                //2.判断实验中学是否已经审核
                if (!$is_sxzx) {
                    $is_exist = ScheduleApproveLog::query()->where('status', ModelStatusEnum::OK)->where('schedule_approve_id', $schedule_approve_id)->where('term_id', $term_id)->where('type', ScheduleApproveLog::TYPE_SYZX)->where('check_status', CheckStatusEnum::OK)->exists();
                    if (!$is_exist) {
                        ScheduleApproveLog::query()->create([
                            'schedule_approve_id' => $schedule_approve_id,
                            'term_id' => $term_id,
                            'type' => ScheduleApproveLog::TYPE_SYZX,
                            'check_status' => $check_status,
                            'check_result' => $check_result,
                            'check_time' => Carbon::now()->toDateTimeString(),
                            'check_admin_id' => $admin_id,
                            'status' => ModelStatusEnum::OK
                        ]);

                        if ($check_status == CheckStatusEnum::ERROR) {
                            $scheduleApproveModel->status = LessonScheduleApproveStatusEnum::STZX_ERROR;
                            $is_sxzx = 2;
                        }
                    }
                }
                if (!$is_sxzx) $scheduleApproveModel->status = LessonScheduleApproveStatusEnum::SYZX_OK;
                $scheduleApproveModel->save();
                break;
        }

        if ($scheduleApproveModel->status == LessonScheduleApproveStatusEnum::SYZX_OK) {
            //停课或者迁移操作
            switch ($scheduleApproveModel->type) {
                case ScheduleRecordTypeEnum::SK:
                    //停课
                    $lessonSchedule = LessonSchedule::query()->find($scheduleApproveModel->lesson_schedule_id);
                    $lessonSchedule->status = LessonScheduleStatusEnum::SJ;
                    $lessonSchedule->save();

                    $scheduleApproveModel->status = LessonScheduleApproveStatusEnum::COMPLETE;
                    $scheduleApproveModel->save();

                    break;
                case ScheduleRecordTypeEnum::TK:
                case ScheduleRecordTypeEnum::BK:
                    //调课

                    //1.判断调到那个地方是否有课
                    $migrate_where = Arr::only($scheduleApproveModel->migrate_data, ['week', 'time_id', 'week_index', 'room_id', 'time_id']);
                    //查看当前调课是否存在课程
                    $is_t_exist = LessonSchedule::query()->where($migrate_where)->where('status', ModelStatusEnum::OK)->exists();
                    if (!$is_t_exist) {
                        //2.停课
                        $lessonSchedule = LessonSchedule::query()->find($scheduleApproveModel->lesson_schedule_id);
                        $lessonSchedule->status = LessonScheduleStatusEnum::TK;
                        $lessonSchedule->save();


                        //3.调课
                        LessonSchedule::query()->create([
                            'term_id' => $lessonSchedule->term_id,
                            'lesson_teacher_id' => $lessonSchedule->lesson_teacher_id,

                            'week' => $migrate_where['week'],
                            'week_index' => $migrate_where['week_index'],
                            'day' => LessonSchedule::byTimeGetDate($lessonSchedule->term_id, $migrate_where['week'], $migrate_where['week_index']),
                            'time_id' => $migrate_where['time_id'],

                            'room_id' => $migrate_where['room_id'],
                            'lesson_id' => $lessonSchedule->lesson_id,
                            'grade_id' => $lessonSchedule->grade_id,
                            'group' => $lessonSchedule->group,
                            'student_nums' => $lessonSchedule->student_nums,
                            'migrate_id' => $lessonSchedule->id,

                            'teach_type' => $lessonSchedule->teach_type,
                            'class_hour' => $lessonSchedule->class_hour,
                            'teach_title' => $lessonSchedule->teach_title,
                            'teacher_id' => $lessonSchedule->teacher_id,
                            'teach_teacher_ids' => $lessonSchedule->teach_teacher_ids,
                            'teacher_admin_id' => $lessonSchedule->teacher_admin_id,
                            'status' => ModelStatusEnum::OK,
                            'type' => ScheduleTypeEnum::LESSON
                        ]);

                        $scheduleApproveModel->status = LessonScheduleApproveStatusEnum::COMPLETE;
                        $scheduleApproveModel->save();
                    } else {
                        $scheduleApproveModel->status = LessonScheduleApproveStatusEnum::OPERATION_ERROR;
                        $scheduleApproveModel->operation_msg = '课程冲突';
                        $scheduleApproveModel->save();
                    }
                    break;
            }
        }
        return false;
    }

    private function error($msg)
    {
        return $msg;
        return [
            'status' => false,
            'msg' => $msg,
        ];
    }
}
