<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

use App\Repositories\Enums\Lab\OpenAppointmentStatusEnum;
use App\Repositories\Enums\ResponseCodeEnum;
use App\Repositories\Enums\ModelStatusEnum;
use App\Repositories\Enums\PermissionEnum;

use App\Repositories\Enums\SexEnum;
use App\Repositories\Enums\CheckStatusEnum;

use App\Repositories\Enums\Base\BannerPositionEnum;
use App\Repositories\Enums\Base\BannerClickTypeEnum;

use App\Repositories\Enums\Base\RoleEnum;

//高校
use App\Repositories\Enums\School\TimeTypeEnum;
use App\Repositories\Enums\School\TeacherTypeEnum;
use App\Repositories\Enums\School\TeachTypeEnum;
use App\Repositories\Enums\School\LessonScheduleApproveStatusEnum;

//实验室
use App\Repositories\Enums\Lab\ImportStatusEnum;

//通知公告
use App\Repositories\Enums\News\SendStatusEnum;


return [
    //实验室
    ImportStatusEnum::class => [
        ImportStatusEnum::IMPORT_WAIT => '等待读取数据',
        ImportStatusEnum::IMPORT_IN => '读取数据中',
        ImportStatusEnum::IMPORT_OK => '读取数据完成，待审核数据',
        ImportStatusEnum::IMPORT_ERROR => '读取数据出错',
        ImportStatusEnum::CHECK_DATA => '审核成功，待合并主库',
        ImportStatusEnum::MERGE_IN => '合并中',
        ImportStatusEnum::MERGE_ERROR => '合并出错',
        ImportStatusEnum::MERGE_OK => '导入完成',
    ],

    //高校
    TimeTypeEnum::class => [
        TimeTypeEnum::AM => '上午',
        TimeTypeEnum::NO => '中午',
        TimeTypeEnum::PM => '下午',
        TimeTypeEnum::BW => '傍晚',
        TimeTypeEnum::NM => '晚上',
    ],
    TeacherTypeEnum::class => [
        TeacherTypeEnum::BY => '本院',
        TeacherTypeEnum::WY => '外院',
    ],
    TeachTypeEnum::class => [
        TeachTypeEnum::LL => '理论',
        TeachTypeEnum::SJ => '实验',
    ],
    LessonScheduleApproveStatusEnum::class => [
        LessonScheduleApproveStatusEnum::CLOSE => '申请已关闭',
        LessonScheduleApproveStatusEnum::WAIT => '待院系审核',
        LessonScheduleApproveStatusEnum::YX_OK => '院系审核成功，待实验中心审核',
        LessonScheduleApproveStatusEnum::YX_ERROR => '院系审核失败',
        LessonScheduleApproveStatusEnum::SYZX_OK => '实验中心审核通过',
        LessonScheduleApproveStatusEnum::STZX_ERROR => '实验中心审核失败',
        LessonScheduleApproveStatusEnum::COMPLETE => '已完成',
        LessonScheduleApproveStatusEnum::OPERATION_ERROR => '操作失败',
    ],

    OpenAppointmentStatusEnum::class => [
        OpenAppointmentStatusEnum::CLOSE => '申请已关闭',
        OpenAppointmentStatusEnum::WAIT_UPLOAD => '待上传实验室开放申请单',
        OpenAppointmentStatusEnum::WAIT => '待实验中心审核',
        OpenAppointmentStatusEnum::SYZX_OK => '实验中心审核通过，待院系审核',
        OpenAppointmentStatusEnum::STZX_ERROR => '实验中心审核失败',
        OpenAppointmentStatusEnum::YX_OK => '审核成功',
        OpenAppointmentStatusEnum::YX_ERROR => '院系审核失败',
        OpenAppointmentStatusEnum::COMPLETE => '已完成',
        OpenAppointmentStatusEnum::OPERATION_ERROR => '操作失败',
    ],

    SendStatusEnum::class => [
        SendStatusEnum::close => '已关闭',
        SendStatusEnum::wait => '待发送',
        SendStatusEnum::sending => '发送中',
        SendStatusEnum::ok => '发送成功',
        SendStatusEnum::error => '发送失败',
    ],


//    基础
    SexEnum::class => [
        SexEnum::NO => '未知',
        SexEnum::MAN => '男',
        SexEnum::WOMAN => '女'
    ],
    ModelStatusEnum::class => [
        ModelStatusEnum::PAUSE => '隐藏',
        ModelStatusEnum::OK => '显示',
    ],
    BannerPositionEnum::class => [
        BannerPositionEnum::HOME => '首页轮播图'
    ],
    BannerClickTypeEnum::class => [
        BannerClickTypeEnum::NO => '无操作',
        BannerClickTypeEnum::LINK => '连接跳转',
    ],
//    RoleEnum::class => [
//        RoleEnum::STUDENT => '学生',
//        RoleEnum::TEACHER => '老师',
//    ],

    RoleEnum::class => [
        RoleEnum::USER => '用户',
        RoleEnum::ADMIN => '管理员',
        RoleEnum::PROJECT => '项目管理员',
    ],

    // 响应状态码
    ResponseCodeEnum::class => [
        // 成功
        ResponseCodeEnum::HTTP_OK => '操作成功', // 自定义 HTTP 状态码返回消息
        ResponseCodeEnum::HTTP_UNAUTHORIZED => '授权失败',

        // 业务操作成功
        ResponseCodeEnum::SERVICE_REGISTER_SUCCESS => '注册成功',
        ResponseCodeEnum::SERVICE_LOGIN_SUCCESS => '登录成功',

        // 客户端错误
        ResponseCodeEnum::CLIENT_PARAMETER_ERROR => '参数错误',
        ResponseCodeEnum::CLIENT_CREATED_ERROR => '数据已存在',
        ResponseCodeEnum::CLIENT_DELETED_ERROR => '数据不存在',
        ResponseCodeEnum::CLIENT_VALIDATION_ERROR => '表单验证错误',

        // 服务端错误
        ResponseCodeEnum::SYSTEM_ERROR => '服务器错误',
        ResponseCodeEnum::SYSTEM_UNAVAILABLE => '服务器正在维护，暂不可用',
        ResponseCodeEnum::SYSTEM_CACHE_CONFIG_ERROR => '缓存配置错误',
        ResponseCodeEnum::SYSTEM_CACHE_MISSED_ERROR => '缓存未命中',
        ResponseCodeEnum::SYSTEM_CONFIG_ERROR => '系统配置错误',

        // 业务操作失败：授权业务
        ResponseCodeEnum::SERVICE_REGISTER_ERROR => '注册失败',
        ResponseCodeEnum::SERVICE_LOGIN_ERROR => '登录失败',
    ],


    CheckStatusEnum::class => [
        CheckStatusEnum::WAIT => '待审核',
        CheckStatusEnum::OK => '审核成功',
        CheckStatusEnum::ERROR => '审核失败',
    ],


//    // 角色
//    RoleEnum::class => [
//        RoleEnum::SUPER_ADMIN => '超级管理员',
//        RoleEnum::GUEST => '游客',
//        RoleEnum::ADMIN => '管理员',
//    ],

//    // 权限
    PermissionEnum::class => [
        PermissionEnum::controller_task_list => '是否可以查看任务',
        PermissionEnum::controller_task_add => '是否可以添加编辑任务',
        PermissionEnum::controller_task_del => '是否可以删除任务',
        PermissionEnum::controller_task_allot => '是否可以分配任务',
        PermissionEnum::controller_task_allot_all => '是否可以分配任务【管理员】',
        PermissionEnum::model_task_all => '全部任务数据',
        PermissionEnum::model_task_me => '我的任务数据',


        PermissionEnum::controller_paper_list => '是否可以查看试卷',
        PermissionEnum::controller_paper_add => '是否可以查看试卷',
        PermissionEnum::controller_paper_del => '是否可以查看试卷',
        PermissionEnum::model_paper_all => '全部试卷数据',
        PermissionEnum::model_paper_monitor => '班长试卷数据',
        PermissionEnum::model_paper_me => '我的试卷数据',

        PermissionEnum::controller_paperResult_list => '是否可以查看工单',
        PermissionEnum::controller_paperResult_add => '是否可以查看工单',
        PermissionEnum::controller_paperResult_del => '是否可以查看工单',
        PermissionEnum::controller_paperResult_answer => '是否可以查看工单',
        PermissionEnum::model_paperResult_all => '全部工单数据',
        PermissionEnum::model_paperResult_monitor => '班长工单数据',
        PermissionEnum::model_paperResult_me => '我的工单数据',

        PermissionEnum::controller_admin_list => '是否可以查看管理员',
        PermissionEnum::controller_admin_add => '是否可以查看管理员',
        PermissionEnum::controller_admin_del => '是否可以查看管理员',
        PermissionEnum::model_admin_all => '全部管理员数据',
        PermissionEnum::model_admin_monitor => '我负责管理员数据',


    ],
];
